Class: Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyApiLifecycle

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb

Overview

Lifecycle information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromePolicyVersionsV1PolicyApiLifecycle

Returns a new instance of GoogleChromePolicyVersionsV1PolicyApiLifecycle.



645
646
647
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprecated_in_favor_ofArray<String>

In the event that this policy was deprecated in favor of another policy, the fully qualified namespace(s) of the new policies as they will show in PolicyAPI. Could only be set if policy_api_lifecycle_stage is API_DEPRECATED. Corresponds to the JSON property deprecatedInFavorOf

Returns:

  • (Array<String>)


614
615
616
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 614

def deprecated_in_favor_of
  @deprecated_in_favor_of
end

#descriptionString

Description about current life cycle. Corresponds to the JSON property description

Returns:

  • (String)


619
620
621
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 619

def description
  @description
end

#end_supportGoogle::Apis::ChromepolicyV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property endSupport



631
632
633
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 631

def end_support
  @end_support
end

#policy_api_lifecycle_stageString

Indicates current life cycle stage of the policy API. Corresponds to the JSON property policyApiLifecycleStage

Returns:

  • (String)


636
637
638
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 636

def policy_api_lifecycle_stage
  @policy_api_lifecycle_stage
end

#scheduled_to_deprecate_policiesArray<String>

Corresponding to deprecated_in_favor_of, the fully qualified namespace(s) of the old policies that will be deprecated because of introduction of this policy. Corresponds to the JSON property scheduledToDeprecatePolicies

Returns:

  • (Array<String>)


643
644
645
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 643

def scheduled_to_deprecate_policies
  @scheduled_to_deprecate_policies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



650
651
652
653
654
655
656
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 650

def update!(**args)
  @deprecated_in_favor_of = args[:deprecated_in_favor_of] if args.key?(:deprecated_in_favor_of)
  @description = args[:description] if args.key?(:description)
  @end_support = args[:end_support] if args.key?(:end_support)
  @policy_api_lifecycle_stage = args[:policy_api_lifecycle_stage] if args.key?(:policy_api_lifecycle_stage)
  @scheduled_to_deprecate_policies = args[:scheduled_to_deprecate_policies] if args.key?(:scheduled_to_deprecate_policies)
end