Class: Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaFieldDescription

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb

Overview

Provides detailed information for a particular field that is part of a PolicySchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromePolicyVersionsV1PolicySchemaFieldDescription

Returns a new instance of GoogleChromePolicyVersionsV1PolicySchemaFieldDescription.



938
939
940
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueObject

Output only. Client default if the policy is unset. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


879
880
881
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 879

def default_value
  @default_value
end

#descriptionString

Deprecated. Use name and field_description instead. The description for the field. Corresponds to the JSON property description

Returns:

  • (String)


885
886
887
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 885

def description
  @description
end

#fieldString

Output only. The name of the field for associated with this description. Corresponds to the JSON property field

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 890

def field
  @field
end

#field_constraintsGoogle::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1FieldConstraints

Information about any range constraints. Corresponds to the JSON property fieldConstraints



895
896
897
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 895

def field_constraints
  @field_constraints
end

#field_dependenciesArray<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaFieldDependencies>

Output only. Provides a list of fields and values. At least one of the fields must have the corresponding value in order for this field to be allowed to be set. Corresponds to the JSON property fieldDependencies



902
903
904
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 902

def field_dependencies
  @field_dependencies
end

#field_descriptionString

Output only. The description of the field. Corresponds to the JSON property fieldDescription

Returns:

  • (String)


907
908
909
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 907

def field_description
  @field_description
end

#input_constraintString

Output only. Any input constraints associated on the values for the field. Corresponds to the JSON property inputConstraint

Returns:

  • (String)


912
913
914
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 912

def input_constraint
  @input_constraint
end

#known_value_descriptionsArray<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaFieldKnownValueDescription>

Output only. If the field has a set of known values, this field will provide a description for these values. Corresponds to the JSON property knownValueDescriptions



918
919
920
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 918

def known_value_descriptions
  @known_value_descriptions
end

#nameString

Output only. The name of the field. Corresponds to the JSON property name

Returns:

  • (String)


923
924
925
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 923

def name
  @name
end

#nested_field_descriptionsArray<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaFieldDescription>

Output only. Provides the description of the fields nested in this field, if the field is a message type that defines multiple fields. Fields are suggested to be displayed by the ordering in this list, not by field number. Corresponds to the JSON property nestedFieldDescriptions



930
931
932
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 930

def nested_field_descriptions
  @nested_field_descriptions
end

#required_itemsArray<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaRequiredItems>

Output only. Provides a list of fields that are required to be set if this field has a certain value. Corresponds to the JSON property requiredItems



936
937
938
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 936

def required_items
  @required_items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



943
944
945
946
947
948
949
950
951
952
953
954
955
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 943

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @field = args[:field] if args.key?(:field)
  @field_constraints = args[:field_constraints] if args.key?(:field_constraints)
  @field_dependencies = args[:field_dependencies] if args.key?(:field_dependencies)
  @field_description = args[:field_description] if args.key?(:field_description)
  @input_constraint = args[:input_constraint] if args.key?(:input_constraint)
  @known_value_descriptions = args[:known_value_descriptions] if args.key?(:known_value_descriptions)
  @name = args[:name] if args.key?(:name)
  @nested_field_descriptions = args[:nested_field_descriptions] if args.key?(:nested_field_descriptions)
  @required_items = args[:required_items] if args.key?(:required_items)
end