Class: Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1UploadPolicyFileRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb

Overview

Request message for uploading a file for a policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromePolicyVersionsV1UploadPolicyFileRequest

Returns a new instance of GoogleChromePolicyVersionsV1UploadPolicyFileRequest.



1372
1373
1374
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_fieldString

Required. The fully qualified policy schema and field name this file is uploaded for. This information will be used to validate the content type of the file. Corresponds to the JSON property policyField

Returns:

  • (String)


1370
1371
1372
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1370

def policy_field
  @policy_field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1377
1378
1379
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1377

def update!(**args)
  @policy_field = args[:policy_field] if args.key?(:policy_field)
end