Class: Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchema
- Inherits:
-
Object
- Object
- Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb
Overview
Resource representing a policy schema.
Instance Attribute Summary collapse
-
#access_restrictions ⇒ Array<String>
Output only.
-
#additional_target_key_names ⇒ Array<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1AdditionalTargetKeyName>
Output only.
-
#category_title ⇒ String
Title of the category in which a setting belongs.
-
#definition ⇒ Google::Apis::ChromepolicyV1::Proto2FileDescriptorProto
Describes a complete .proto file.
-
#field_descriptions ⇒ Array<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaFieldDescription>
Output only.
-
#name ⇒ String
Format: name=customers/
customer/policySchemas/schema_namespaceCorresponds to the JSON propertyname. -
#notices ⇒ Array<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription>
Output only.
-
#policy_api_lifecycle ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyApiLifecycle
Lifecycle information.
-
#policy_description ⇒ String
Output only.
-
#schema_name ⇒ String
Output only.
-
#support_uri ⇒ String
Output only.
-
#supported_platforms ⇒ Array<String>
Output only.
-
#valid_target_resources ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromePolicyVersionsV1PolicySchema
constructor
A new instance of GoogleChromePolicyVersionsV1PolicySchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromePolicyVersionsV1PolicySchema
Returns a new instance of GoogleChromePolicyVersionsV1PolicySchema.
823 824 825 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_restrictions ⇒ Array<String>
Output only. Specific access restrictions related to this policy.
Corresponds to the JSON property accessRestrictions
752 753 754 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 752 def access_restrictions @access_restrictions end |
#additional_target_key_names ⇒ Array<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1AdditionalTargetKeyName>
Output only. Additional key names that will be used to identify the target of
the policy value. When specifying a policyTargetKey, each of the additional
keys specified here will have to be included in the additionalTargetKeys map.
Corresponds to the JSON property additionalTargetKeyNames
759 760 761 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 759 def additional_target_key_names @additional_target_key_names end |
#category_title ⇒ String
Title of the category in which a setting belongs.
Corresponds to the JSON property categoryTitle
764 765 766 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 764 def category_title @category_title end |
#definition ⇒ Google::Apis::ChromepolicyV1::Proto2FileDescriptorProto
Describes a complete .proto file.
Corresponds to the JSON property definition
769 770 771 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 769 def definition @definition end |
#field_descriptions ⇒ Array<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaFieldDescription>
Output only. Detailed description of each field that is part of the schema.
Fields are suggested to be displayed by the ordering in this list, not by
field number.
Corresponds to the JSON property fieldDescriptions
776 777 778 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 776 def field_descriptions @field_descriptions end |
#name ⇒ String
Format: name=customers/customer/policySchemas/schema_namespace
Corresponds to the JSON property name
781 782 783 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 781 def name @name end |
#notices ⇒ Array<Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription>
Output only. Special notice messages related to setting certain values in
certain fields in the schema.
Corresponds to the JSON property notices
787 788 789 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 787 def notices @notices end |
#policy_api_lifecycle ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyApiLifecycle
Lifecycle information.
Corresponds to the JSON property policyApiLifecycle
792 793 794 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 792 def policy_api_lifecycle @policy_api_lifecycle end |
#policy_description ⇒ String
Output only. Description about the policy schema for user consumption.
Corresponds to the JSON property policyDescription
797 798 799 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 797 def policy_description @policy_description end |
#schema_name ⇒ String
Output only. The fully qualified name of the policy schema. This value is used
to fill the field policy_schema in PolicyValue when calling
BatchInheritOrgUnitPolicies BatchModifyOrgUnitPolicies
BatchModifyGroupPolicies or BatchDeleteGroupPolicies.
Corresponds to the JSON property schemaName
805 806 807 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 805 def schema_name @schema_name end |
#support_uri ⇒ String
Output only. URI to related support article for this schema.
Corresponds to the JSON property supportUri
810 811 812 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 810 def support_uri @support_uri end |
#supported_platforms ⇒ Array<String>
Output only. List indicates that the policy will only apply to devices/users
on these platforms.
Corresponds to the JSON property supportedPlatforms
816 817 818 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 816 def supported_platforms @supported_platforms end |
#valid_target_resources ⇒ Array<String>
Output only. Information about applicable target resources for the policy.
Corresponds to the JSON property validTargetResources
821 822 823 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 821 def valid_target_resources @valid_target_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 828 def update!(**args) @access_restrictions = args[:access_restrictions] if args.key?(:access_restrictions) @additional_target_key_names = args[:additional_target_key_names] if args.key?(:additional_target_key_names) @category_title = args[:category_title] if args.key?(:category_title) @definition = args[:definition] if args.key?(:definition) @field_descriptions = args[:field_descriptions] if args.key?(:field_descriptions) @name = args[:name] if args.key?(:name) @notices = args[:notices] if args.key?(:notices) @policy_api_lifecycle = args[:policy_api_lifecycle] if args.key?(:policy_api_lifecycle) @policy_description = args[:policy_description] if args.key?(:policy_description) @schema_name = args[:schema_name] if args.key?(:schema_name) @support_uri = args[:support_uri] if args.key?(:support_uri) @supported_platforms = args[:supported_platforms] if args.key?(:supported_platforms) @valid_target_resources = args[:valid_target_resources] if args.key?(:valid_target_resources) end |