Class: Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription
- Inherits:
-
Object
- Object
- Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb
Overview
Provides special notice messages related to a particular value in a field that is part of a PolicySchema.
Instance Attribute Summary collapse
-
#acknowledgement_required ⇒ Boolean
(also: #acknowledgement_required?)
Output only.
-
#field ⇒ String
Output only.
-
#notice_message ⇒ String
Output only.
-
#notice_value ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription
constructor
A new instance of GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription
Returns a new instance of GoogleChromePolicyVersionsV1PolicySchemaNoticeDescription.
1020 1021 1022 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acknowledgement_required ⇒ Boolean Also known as: acknowledgement_required?
Output only. Whether the user needs to acknowledge the notice message before
the value can be set.
Corresponds to the JSON property acknowledgementRequired
1000 1001 1002 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1000 def acknowledgement_required @acknowledgement_required end |
#field ⇒ String
Output only. The field name associated with the notice.
Corresponds to the JSON property field
1006 1007 1008 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1006 def field @field end |
#notice_message ⇒ String
Output only. The notice message associate with the value of the field.
Corresponds to the JSON property noticeMessage
1011 1012 1013 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1011 def @notice_message end |
#notice_value ⇒ String
Output only. The value of the field that has a notice. When setting the field
to this value, the user may be required to acknowledge the notice message in
order for the value to be set.
Corresponds to the JSON property noticeValue
1018 1019 1020 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1018 def notice_value @notice_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1025 1026 1027 1028 1029 1030 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1025 def update!(**args) @acknowledgement_required = args[:acknowledgement_required] if args.key?(:acknowledgement_required) @field = args[:field] if args.key?(:field) @notice_message = args[:notice_message] if args.key?(:notice_message) @notice_value = args[:notice_value] if args.key?(:notice_value) end |