Class: Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1ResolvedPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1ResolvedPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb
Overview
The resolved value of a policy for a given target.
Instance Attribute Summary collapse
-
#added_source_key ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyTargetKey
The key used to identify the target on which the policy will be applied.
-
#source_key ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyTargetKey
The key used to identify the target on which the policy will be applied.
-
#target_key ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyTargetKey
The key used to identify the target on which the policy will be applied.
-
#value ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyValue
A particular value for a policy managed by the service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromePolicyVersionsV1ResolvedPolicy
constructor
A new instance of GoogleChromePolicyVersionsV1ResolvedPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromePolicyVersionsV1ResolvedPolicy
Returns a new instance of GoogleChromePolicyVersionsV1ResolvedPolicy.
1311 1312 1313 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#added_source_key ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyTargetKey
The key used to identify the target on which the policy will be applied.
Corresponds to the JSON property addedSourceKey
1294 1295 1296 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1294 def added_source_key @added_source_key end |
#source_key ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyTargetKey
The key used to identify the target on which the policy will be applied.
Corresponds to the JSON property sourceKey
1299 1300 1301 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1299 def source_key @source_key end |
#target_key ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyTargetKey
The key used to identify the target on which the policy will be applied.
Corresponds to the JSON property targetKey
1304 1305 1306 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1304 def target_key @target_key end |
#value ⇒ Google::Apis::ChromepolicyV1::GoogleChromePolicyVersionsV1PolicyValue
A particular value for a policy managed by the service.
Corresponds to the JSON property value
1309 1310 1311 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1309 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1316 1317 1318 1319 1320 1321 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1316 def update!(**args) @added_source_key = args[:added_source_key] if args.key?(:added_source_key) @source_key = args[:source_key] if args.key?(:source_key) @target_key = args[:target_key] if args.key?(:target_key) @value = args[:value] if args.key?(:value) end |