Class: Google::Apis::ChromepolicyV1::Proto2FileDescriptorProto
- Inherits:
-
Object
- Object
- Google::Apis::ChromepolicyV1::Proto2FileDescriptorProto
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromepolicy_v1/classes.rb,
lib/google/apis/chromepolicy_v1/representations.rb,
lib/google/apis/chromepolicy_v1/representations.rb
Overview
Describes a complete .proto file.
Instance Attribute Summary collapse
-
#edition_deprecated ⇒ String
copybara:strip_begin TODO(b/297898292) Deprecate and remove this field in favor of enums.
-
#enum_type ⇒ Array<Google::Apis::ChromepolicyV1::Proto2EnumDescriptorProto>
Corresponds to the JSON property
enumType. -
#message_type ⇒ Array<Google::Apis::ChromepolicyV1::Proto2DescriptorProto>
All top-level definitions in this file.
-
#name ⇒ String
file name, relative to root of source tree Corresponds to the JSON property
name. -
#option_dependency ⇒ Array<String>
Names of files imported by this file purely for the purpose of providing option extensions.
-
#package ⇒ String
e.g.
-
#syntax ⇒ String
The syntax of the proto file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Proto2FileDescriptorProto
constructor
A new instance of Proto2FileDescriptorProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Proto2FileDescriptorProto
Returns a new instance of Proto2FileDescriptorProto.
1726 1727 1728 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition_deprecated ⇒ String
copybara:strip_begin TODO(b/297898292) Deprecate and remove this field in
favor of enums. copybara:strip_end
Corresponds to the JSON property editionDeprecated
1689 1690 1691 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1689 def edition_deprecated @edition_deprecated end |
#enum_type ⇒ Array<Google::Apis::ChromepolicyV1::Proto2EnumDescriptorProto>
Corresponds to the JSON property enumType
1694 1695 1696 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1694 def enum_type @enum_type end |
#message_type ⇒ Array<Google::Apis::ChromepolicyV1::Proto2DescriptorProto>
All top-level definitions in this file.
Corresponds to the JSON property messageType
1699 1700 1701 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1699 def @message_type end |
#name ⇒ String
file name, relative to root of source tree
Corresponds to the JSON property name
1704 1705 1706 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1704 def name @name end |
#option_dependency ⇒ Array<String>
Names of files imported by this file purely for the purpose of providing
option extensions. These are excluded from the dependency list above.
Corresponds to the JSON property optionDependency
1710 1711 1712 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1710 def option_dependency @option_dependency end |
#package ⇒ String
e.g. "foo", "foo.bar", etc.
Corresponds to the JSON property package
1715 1716 1717 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1715 def package @package end |
#syntax ⇒ String
The syntax of the proto file. The supported values are "proto2", "proto3", and
"editions". If edition is present, this value must be "editions". WARNING:
This field should only be used by protobuf plugins or special cases like the
proto compiler. Other uses are discouraged and developers should rely on the
protoreflect APIs for their client language.
Corresponds to the JSON property syntax
1724 1725 1726 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1724 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1731 1732 1733 1734 1735 1736 1737 1738 1739 |
# File 'lib/google/apis/chromepolicy_v1/classes.rb', line 1731 def update!(**args) @edition_deprecated = args[:edition_deprecated] if args.key?(:edition_deprecated) @enum_type = args[:enum_type] if args.key?(:enum_type) @message_type = args[:message_type] if args.key?(:message_type) @name = args[:name] if args.key?(:name) @option_dependency = args[:option_dependency] if args.key?(:option_dependency) @package = args[:package] if args.key?(:package) @syntax = args[:syntax] if args.key?(:syntax) end |